
![](https://www.phonexia.com/wp-content/uploads/phonexia-logo-transparent-500px.png)

# Phonexia speaker diarization client

This module contains client for communication with [voiceprint diarization microservice](https://hub.docker.com/repository/docker/phonexia/speaker-diarization/general) developed by [Phonexia](https://phonexia.com).

To use this client you will first need a running instance of any *Phonexia speaker diarization microservice*. If you don't yet have any running instance, don't hesitate to [contact our sales department](mailto:info@phonexia.com).

You can learn more about the speaker diarization technology [here](TODO).

On [this page](TODO), you will find a *gRPC API* reference for *voiceprint diarization microservice*.